Ueberauth.Strategy.DocuSign.OAuth (Ueberauth DocuSign v0.1.0)

OAuth2 client for DocuSign.

Configures the OAuth2 strategy for DocuSign authentication.

Summary

Functions

Provides the authorize url for the request phase of Ueberauth. No need to call this usually.

Construct a client for requests to DocuSign.

Functions

authorize_url(client, params)

Callback implementation for OAuth2.Strategy.authorize_url/2.

authorize_url!(params \\ [], opts \\ [])

Provides the authorize url for the request phase of Ueberauth. No need to call this usually.

client(opts \\ [])

Construct a client for requests to DocuSign.

This will be setup automatically for you in Ueberauth.Strategy.DocuSign.

These options are only useful for usage outside the normal callback phase of Ueberauth.

get(token, url, headers \\ [], opts \\ [])

get_access_token(params \\ [], opts \\ [])

get_token(client, params, headers)

Callback implementation for OAuth2.Strategy.get_token/3.