Ueberauth.Strategy.DocuSign.OAuth (Ueberauth DocuSign v0.1.0)
View SourceOAuth2 client for DocuSign.
Configures the OAuth2 strategy for DocuSign authentication.
Summary
Functions
Callback implementation for OAuth2.Strategy.authorize_url/2.
Provides the authorize url for the request phase of Ueberauth. No need to call this usually.
Construct a client for requests to DocuSign.
Callback implementation for OAuth2.Strategy.get_token/3.
Functions
Callback implementation for OAuth2.Strategy.authorize_url/2.
Provides the authorize url for the request phase of Ueberauth. No need to call this usually.
Construct a client for requests to DocuSign.
This will be setup automatically for you in Ueberauth.Strategy.DocuSign.
These options are only useful for usage outside the normal callback phase of Ueberauth.
Callback implementation for OAuth2.Strategy.get_token/3.